@@ -1,17 +1,17 @@
 import functools
-import sys
 from typing import (
     Any,
     Awaitable,
     Callable,
     Dict,
+    Final,
     Mapping,
     Optional,
+    Protocol,
     Sequence,
     Tuple,
     TypeVar,
     Union,
-    cast,
     overload,
 )
 
@@ -19,27 +19,30 @@ import jinja2
 from aiohttp import web
 from aiohttp.abc import AbstractView
 
-if sys.version_info >= (3, 8):
-    from typing import Protocol
-else:
-    from typing_extensions import Protocol
-
-from .helpers import GLOBAL_HELPERS
+from .helpers import GLOBAL_HELPERS, static_root_key
 from .typedefs import Filters
 
-__version__ = "1.5.1"
+__version__ = "1.6"
 
-__all__ = ("setup", "get_env", "render_template", "render_string", "template")
-
-
-APP_CONTEXT_PROCESSORS_KEY = "aiohttp_jinja2_context_processors"
-APP_KEY = "aiohttp_jinja2_environment"
-REQUEST_CONTEXT_KEY = "aiohttp_jinja2_context"
+__all__ = (
+    "get_env",
+    "render_string",
+    "render_template",
+    "setup",
+    "static_root_key",
+    "template",
+)
 
 _TemplateReturnType = Awaitable[Union[web.StreamResponse, Mapping[str, Any]]]
 _SimpleTemplateHandler = Callable[[web.Request], _TemplateReturnType]
 _ContextProcessor = Callable[[web.Request], Awaitable[Dict[str, Any]]]
 
+APP_CONTEXT_PROCESSORS_KEY: Final = web.AppKey[Sequence[_ContextProcessor]](
+    "APP_CONTEXT_PROCESSORS_KEY"
+)
+APP_KEY: Final = web.AppKey[jinja2.Environment]("APP_KEY")
+REQUEST_CONTEXT_KEY: Final = "aiohttp_jinja2_context"
+
 _T = TypeVar("_T")
 _AbstractView = TypeVar("_AbstractView", bound=AbstractView)
 
@@ -67,7 +70,7 @@ class _TemplateWrapper(Protocol):
 def setup(
     app: web.Application,
     *args: Any,
-    app_key: str = APP_KEY,
+    app_key: web.AppKey[jinja2.Environment] = APP_KEY,
     context_processors: Sequence[_ContextProcessor] = (),
     filters: Optional[Filters] = None,
     default_helpers: bool = True,
@@ -89,23 +92,24 @@ def setup(
     return env
 
 
-def get_env(app: web.Application, *, app_key: str = APP_KEY) -> jinja2.Environment:
-    return cast(jinja2.Environment, app.get(app_key))
+def get_env(
+    app: web.Application, *, app_key: web.AppKey[jinja2.Environment] = APP_KEY
+) -> jinja2.Environment:
+    try:
+        return app[app_key]
+    except KeyError:
+        raise RuntimeError("aiohttp_jinja2.setup(...) must be called first.")
 
 
 def _render_string(
     template_name: str,
     request: web.Request,
     context: Mapping[str, Any],
-    app_key: str,
+    app_key: web.AppKey[jinja2.Environment],
 ) -> Tuple[jinja2.Template, Mapping[str, Any]]:
     env = request.config_dict.get(app_key)
     if env is None:
-        text = (
-            "Template engine is not initialized, "
-            "call aiohttp_jinja2.setup(..., app_key={}) first"
-            "".format(app_key)
-        )
+        text = "Template engine is not initialized, call aiohttp_jinja2.setup() first"
         # in order to see meaningful exception message both: on console
         # output and rendered page we add same message to *reason* and
         # *text* arguments.
@@ -129,7 +133,7 @@ def render_string(
     request: web.Request,
     context: Mapping[str, Any],
     *,
-    app_key: str = APP_KEY,
+    app_key: web.AppKey[jinja2.Environment] = APP_KEY,
 ) -> str:
     template, context = _render_string(template_name, request, context, app_key)
     return template.render(context)
@@ -140,7 +144,7 @@ async def render_string_async(
     request: web.Request,
     context: Mapping[str, Any],
     *,
-    app_key: str = APP_KEY,
+    app_key: web.AppKey[jinja2.Environment] = APP_KEY,
 ) -> str:
     template, context = _render_string(template_name, request, context, app_key)
     return await template.render_async(context)
@@ -164,7 +168,7 @@ def render_template(
     request: web.Request,
     context: Optional[Mapping[str, Any]],
     *,
-    app_key: str = APP_KEY,
+    app_key: web.AppKey[jinja2.Environment] = APP_KEY,
     encoding: str = "utf-8",
     status: int = 200,
 ) -> web.Response:
@@ -178,7 +182,7 @@ async def render_template_async(
     request: web.Request,
     context: Optional[Mapping[str, Any]],
     *,
-    app_key: str = APP_KEY,
+    app_key: web.AppKey[jinja2.Environment] = APP_KEY,
     encoding: str = "utf-8",
     status: int = 200,
 ) -> web.Response:
@@ -192,7 +196,7 @@ async def render_template_async(
 def template(
     template_name: str,
     *,
-    app_key: str = APP_KEY,
+    app_key: web.AppKey[jinja2.Environment] = APP_KEY,
     encoding: str = "utf-8",
     status: int = 200,
 ) -> _TemplateWrapper:
@@ -253,7 +257,6 @@ async def context_processors_middleware(
     request: web.Request,
     handler: Callable[[web.Request], Awaitable[web.StreamResponse]],
 ) -> web.StreamResponse:
-
     if REQUEST_CONTEXT_KEY not in request:
         request[REQUEST_CONTEXT_KEY] = {}
     for processor in request.config_dict[APP_CONTEXT_PROCESSORS_KEY]:
