@@ -2,21 +2,19 @@
 useful context functions, see
 http://jinja.pocoo.org/docs/dev/api/#jinja2.contextfunction
 """
-import sys
-from typing import Any, Dict, Optional, Union
+import warnings
+from typing import Dict, Optional, TypedDict, Union
 
 import jinja2
 from aiohttp import web
 from yarl import URL
 
-if sys.version_info >= (3, 8):
-    from typing import TypedDict
 
-    class _Context(TypedDict, total=False):
-        app: web.Application
+class _Context(TypedDict, total=False):
+    app: web.Application
 
-else:
-    _Context = Dict[str, Any]
+
+static_root_key = web.AppKey("static_root_key", str)
 
 
 @jinja2.pass_context
@@ -61,21 +59,30 @@ def url_for(
 def static_url(context: _Context, static_file_path: str) -> str:
     """Filter for generating urls for static files.
 
-    NOTE: you'll need
-    to set app['static_root_url'] to be used as the root for the urls returned.
+    NOTE: you'll need to set app[aiohttp_jinja2.static_root_key] to be used as the
+    root for the urls returned.
 
     Usage: {{ static('styles.css') }} might become
     "/static/styles.css" or "http://mycdn.example.com/styles.css"
     """
     app = context["app"]
     try:
-        static_url = app["static_root_url"]
+        static_url = app[static_root_key]
     except KeyError:
-        raise RuntimeError(
-            "app does not define a static root url "
-            "'static_root_url', you need to set the url root "
-            "with app['static_root_url'] = '<static root>'."
-        ) from None
+        try:
+            # TODO (aiohttp 3.10+): Remove this fallback
+            static_url = app["static_root_url"]
+        except KeyError:
+            raise RuntimeError(
+                "app does not define a static root url, you need to set the url root "
+                "with app[aiohttp_jinja2.static_root_key] = '<static root>'."
+            ) from None
+        else:
+            warnings.warn(
+                "'static_root_url' is deprecated, use aiohttp_jinja2.static_root_key.",
+                category=DeprecationWarning,
+                stacklevel=2,
+            )
     return "{}/{}".format(static_url.rstrip("/"), static_file_path.lstrip("/"))
 
 
